@@ -1,12 +1,11 @@
 import uuid
-import orjson
+import json
 from datetime import datetime
 from enum import Enum
 from typing import Any, Type, Dict, List, Optional, KeysView, Set, Union
-from pydantic import BaseModel, parse_obj_as
+from pydantic import BaseModel, Field, parse_obj_as
 import zstandard
 
-from .helpers import orjson_dumps
 from .exception import PipelineMessageError
 
 
@@ -25,21 +24,21 @@ class Log(BaseModel):
     elapsed: Optional[float] = None
 
 
+def hex_uuid():
+    return uuid.uuid1().hex
+
+
 class MessageBase(BaseModel):
     """:class:`Message` is a container for data in pipeline. Data will be wrapped in
     :class:`Message` in order to pass through a pipeline constructed with this library.
     """
 
     kind: Kind = Kind.Base
-    id: str = uuid.uuid1().hex
-    created: datetime = datetime.now()
+    id: str = Field(default_factory=hex_uuid)
+    created: datetime = Field(default_factory=datetime.now)
     logs: List[Log] = []
     content: Dict[str, Any] = {}
 
-    class Config:
-        json_loads = orjson.loads
-        json_dumps = orjson_dumps
-
     def serialize(self, compress: bool = False) -> bytes:
         return serialize_message(self, compress)
 
@@ -47,7 +46,9 @@ class MessageBase(BaseModel):
     def deserialize(self, raw: bytes) -> "MessageBase":
         return deserialize_message(raw)
 
-    def as_model(self, model_class: Type[BaseModel]) -> BaseModel:
+    def as_model(
+        self, model_class: Type[BaseModel], mappings: Optional[Dict[str, str]] = None
+    ) -> BaseModel:
         """return content as another BaseModel instance
 
         Parameters:
@@ -56,7 +57,11 @@ class MessageBase(BaseModel):
             :return: BaseModel
             :rtype: BaseModel
         """
-        return model_class(**self.content)
+        if mappings:
+            content = {mappings.get(k, k): v for k, v in self.content.items()}
+        else:
+            content = self.content
+        return model_class(**content)
 
     def update_content(self, other: BaseModel) -> KeysView[str]:
         """add fields from other model to update message's content
@@ -116,9 +121,9 @@ def serialize_message(message: MessageBase, compress: bool = False) -> bytes:
 
 def deserialize_message(raw: bytes) -> Union[Message, Command]:
     if raw[0] == ord("{"):
-        message_dict = orjson.loads(raw.decode("utf-8"))
+        message_dict = json.loads(raw.decode("utf-8"))
     elif raw[0] == ord("Z"):
-        message_dict = orjson.loads(zstandard.decompress(raw[1:]).decode("utf-8"))
+        message_dict = json.loads(zstandard.decompress(raw[1:]).decode("utf-8"))
     else:
         raise PipelineMessageError("Unknown bytes string cannot be deserialized")
 
