@@ -3,7 +3,7 @@ import csv
 import logging
 import sys
 import gzip
-import orjson
+import json
 from abc import ABC, abstractmethod
 from logging import Logger
 from enum import Enum
@@ -11,7 +11,7 @@ from typing import Optional, Dict, Tuple, Iterator, List, ClassVar, Type, Union,
 
 from pydantic import BaseModel, Field
 
-from .helpers import Settings
+from .helpers import Settings, parse_mappings
 from .message import MessageBase, Message, deserialize_message, serialize_message
 from .importor import import_class
 
@@ -20,6 +20,14 @@ pipelineLogger = logging.getLogger("pipeline")
 
 
 class BaseSourceSettings(Settings):
+    mappings: str = Field(
+        "",
+        title=(
+            "input field names mapping (e.g. 'content:text,source:url' will rename input's "
+            "content and source fields to text and url)"
+        ),
+    )
+
     class Config:
         env_prefix = "in_"
 
@@ -46,6 +54,7 @@ class SourceTap(ABC):
         self.settings = settings
         self.topic = settings.topic
         self.logger = logger
+        self.mappings = parse_mappings(settings.mappings)
 
     def __str__(self) -> str:
         return self.__repr__()
@@ -232,6 +241,7 @@ class MemoryDestination(DestinationTap):
 
 
 class FileSourceSettings(SourceSettings):
+    keyname: str = Field("", title="field name to be used as key")
     filename: str = Field("-", title="input filename, use '-' for stdin", required=True)
     content_only: bool = Field(True, title="input contains only content for messages")
 
@@ -276,9 +286,11 @@ class FileSource(SourceTap):
     def read(self) -> Iterator[MessageBase]:
         if self.settings.content_only:
             for line in self.infile:
-                content = orjson.loads(line)
-                if content.get("id"):
-                    yield Message(content=content, id=content.get("id"))
+                content = json.loads(line)
+                if self.settings.keyname:
+                    yield Message(
+                        content=content, id=content.get(self.settings.keyname)
+                    )
                 else:
                     yield Message(content=content)
         else:
@@ -333,7 +345,7 @@ class FileDestination(DestinationTap):
 
     def write(self, message: MessageBase) -> int:
         if self.settings.content_only:
-            serialized = orjson.dumps(message.content) + b"\n"
+            serialized = json.dumps(message.content).encode("utf-8") + b"\n"
         else:
             serialized = message.serialize(compress=False) + "\n".encode("utf-8")
         self.outFile.write(serialized)
